@@ -40,11 +40,11 @@ namespace fixedwidth {
     m_note_addin->get_window()->text_menu()->signal_show().connect(
       sigc::mem_fun(*this, &FixedWidthMenuItem::menu_shown));
 
-    add_accelerator ("activate",
-                     addin->get_window()->get_accel_group(),
-                     GDK_KEY_T,
-                     Gdk::CONTROL_MASK,
-                     Gtk::ACCEL_VISIBLE);
+    gnote::NoteWindow *note_window = addin->get_window();
+    note_window->signal_foregrounded.connect(
+      sigc::mem_fun(*this, &FixedWidthMenuItem::on_note_foregrounded));
+    note_window->signal_backgrounded.connect(
+      sigc::mem_fun(*this, &FixedWidthMenuItem::on_note_backgrounded));
 
     show_all();
   }
@@ -66,4 +66,22 @@ namespace fixedwidth {
   }
 
 
+  void FixedWidthMenuItem::on_note_foregrounded()
+  {
+    add_accelerator("activate",
+                    m_note_addin->get_window()->get_accel_group(),
+                    GDK_KEY_T,
+                    Gdk::CONTROL_MASK,
+                    Gtk::ACCEL_VISIBLE);
+  }
+
+
+  void FixedWidthMenuItem::on_note_backgrounded()
+  {
+    remove_accelerator(m_note_addin->get_window()->get_accel_group(),
+                       GDK_KEY_T,
+                       Gdk::CONTROL_MASK);
+  }
+
+
 }
